@@ -4,7 +4,7 @@ from .constants import REQUEST_CORE_REQUEST_KEY, REQUEST_OPENAPI_CONTEXT_KEY
 from .core_data import to_core_openapi_request, to_core_openapi_response
 from .core_validators import validate_core_request, validate_core_response
 from .data import OpenAPIContext
-from .utils import get_openapi_spec
+from .utils import get_openapi_spec, get_validate_email_kwargs
 
 
 async def validate_request(request: web.Request) -> web.Request:
@@ -14,7 +14,9 @@ async def validate_request(request: web.Request) -> web.Request:
     request[REQUEST_CORE_REQUEST_KEY] = core_request
 
     security, parameters, data = validate_core_request(
-        get_openapi_spec(config_dict), core_request
+        get_openapi_spec(config_dict),
+        core_request,
+        validate_email_kwargs=get_validate_email_kwargs(config_dict),
     )
     request[REQUEST_OPENAPI_CONTEXT_KEY] = OpenAPIContext(
         request=request,
@@ -31,9 +33,12 @@ async def validate_request(request: web.Request) -> web.Request:
 def validate_response(
     request: web.Request, response: web.StreamResponse
 ) -> web.StreamResponse:
+    config_dict = request.config_dict
+
     validate_core_response(
-        get_openapi_spec(request.config_dict),
+        get_openapi_spec(config_dict),
         request[REQUEST_CORE_REQUEST_KEY],
         to_core_openapi_response(response),
+        validate_email_kwargs=get_validate_email_kwargs(config_dict),
     )
     return response
